@@ -186,8 +186,9 @@ def run_sampling_opencl(G_m_csr, thresholds_np, shots, n, is_g_buf_reused):
     queue = opencl_context.queue
     kernel = opencl_context.sample_for_solution_best_bitset_sparse_kernel
     dtype = opencl_context.dtype
+    wgs = opencl_context.work_group_size
 
-    max_local_size = 64  # tune
+    max_local_size = wqs  # tune
     max_global_size = ((opencl_context.MAX_GPU_PROC_ELEM + max_local_size - 1) // max_local_size) * max_local_size  # corresponds to MAX_PROC_ELEM macro in OpenCL kernel program
     global_size = min(((shots + max_local_size - 1) // max_local_size) * max_local_size, max_global_size)
     local_size = max_local_size
@@ -313,6 +314,7 @@ def maxcut_tfim_sparse(
     is_base_maxcut_gpu=True
 ):
     dtype = opencl_context.dtype
+    wgs = opencl_context.work_group_size
     nodes = None
     n_qubits = 0
     G_m = None
@@ -349,7 +351,7 @@ def maxcut_tfim_sparse(
     n_steps = n_qubits << quality
     grid_size = n_steps * n_qubits
 
-    if (not is_base_maxcut_gpu) or not (IS_OPENCL_AVAILABLE and grid_size >= 128):
+    if (not is_base_maxcut_gpu) or (not IS_OPENCL_AVAILABLE):
         return cpu_footer(shots, quality, n_qubits, G_m.data, G_m.indptr, G_m.indices, nodes, dtype)
 
     J_eff, degrees = init_J_and_z(G_m.data, G_m.indptr, G_m.indices, dtype)
@@ -371,7 +373,7 @@ def maxcut_tfim_sparse(
     theta_buf = cl.Buffer(opencl_context.ctx, mf.READ_WRITE, size=(n_qubits * 4))
 
     # Warp size is 32:
-    group_size = min(n_qubits, 64)
+    group_size = min(wgs, n_qubits)
     global_size = ((n_qubits + group_size - 1) // group_size) * group_size
 
     opencl_context.init_theta_kernel(
@@ -382,9 +384,7 @@ def maxcut_tfim_sparse(
     hamming_prob = init_thresholds(n_qubits, dtype)
 
     # Warp size is 32:
-    group_size = n_qubits - 1
-    if group_size > 256:
-        group_size = 256
+    group_size = min(wgs, n_qubits - 1)
     grid_dim = n_steps * n_qubits * group_size
 
     # Move to GPU
@@ -417,7 +417,7 @@ def maxcut_tfim_sparse(
         return gpu_footer(shots, n_qubits, G_m.data, G_m.indptr, G_m.indices, J_eff, hamming_prob, nodes, dtype)
 
     fix_cdf(hamming_prob)
-    best_solution, best_value = run_sampling_opencl(G_m, hamming_prob, shots, n_qubits, is_g_buf_reused, dtype)
+    best_solution, best_value = run_sampling_opencl(G_m, hamming_prob, shots, n_qubits, is_g_buf_reused)
     bit_string, l, r = get_cut(best_solution, nodes)
 
     return bit_string, best_value, (l, r)
