@@ -72,6 +72,7 @@ def run_bootstrap_opencl(best_theta, G_m_buf, indices_array_np, k, min_energy):
     queue = opencl_context.queue
     bootstrap_kernel = opencl_context.bootstrap_kernel
     dtype = opencl_context.dtype
+    wgs = opencl_context.work_group_size
 
     n = best_theta.shape[0]
     combo_count = len(indices_array_np) // k
@@ -95,7 +96,7 @@ def run_bootstrap_opencl(best_theta, G_m_buf, indices_array_np, k, min_energy):
     min_index_buf = cl.Buffer(ctx, mf.WRITE_ONLY, min_index_host.nbytes)
 
     # Local memory allocation (1 float per work item)
-    local_size = min(64, n)
+    local_size = min(wgs, n)
     global_size = ((combo_count + local_size - 1) // local_size) * local_size
     local_energy_buf = cl.LocalMemory(np.dtype(dtype).itemsize * local_size)
     local_index_buf = cl.LocalMemory(np.dtype(np.int32).itemsize * local_size)
