@@ -1,4 +1,5 @@
 from .maxcut_tfim_streaming import maxcut_tfim_streaming
+from .maxcut_tfim_util import opencl_context
 from .spin_glass_solver_util import get_cut_from_bit_array, int_to_bitstring
 import itertools
 import networkx as nx
@@ -42,9 +43,9 @@ def bootstrap_worker(theta, G_func, G_func_args_tuple, nodes, indices):
 
 
 @njit(parallel=True)
-def bootstrap(best_theta, G_func, G_func_args_tuple, nodes, indices_array, k, min_energy):
+def bootstrap(best_theta, G_func, G_func_args_tuple, nodes, indices_array, k, min_energy, dtype):
     n = len(indices_array) // k
-    energies = np.empty(n, dtype=np.float32)
+    energies = np.empty(n, dtype=dtype)
     for i in prange(n):
         j = i * k
         energies[i] = bootstrap_worker(best_theta, G_func, G_func_args_tuple, nodes, indices_array[j : j + k])
@@ -66,8 +67,10 @@ def spin_glass_solver_streaming(
     G_func_args_tuple=None,
     quality=None,
     shots=None,
-    best_guess=None
+    best_guess=None,
+    is_base_maxcut_gpu=True
 ):
+    dtype = opencl_context.dtype
     n_qubits = len(nodes)
 
     if n_qubits < 3:
@@ -95,7 +98,7 @@ def spin_glass_solver_streaming(
     elif isinstance(best_guess, list):
         bitstring = "".join(["1" if b else "0" for b in best_guess])
     else:
-        bitstring, _, _ = maxcut_tfim_streaming(G_func, nodes, G_func_args_tuple=G_func_args_tuple, quality=quality, shots=shots)
+        bitstring, _, _ = maxcut_tfim_streaming(G_func, nodes, G_func_args_tuple=G_func_args_tuple, quality=quality, shots=shots, is_base_maxcut_gpu=is_base_maxcut_gpu)
     best_theta = np.array([b == "1" for b in list(bitstring)], dtype=np.bool_)
 
     min_energy = compute_energy(best_theta, G_func, G_func_args_tuple, nodes)
@@ -118,7 +121,7 @@ def spin_glass_solver_streaming(
             else:
                 combos = combos_list[k - 1]
 
-            energy = bootstrap(best_theta, G_func, G_func_args_tuple, nodes, combos, k, min_energy)
+            energy = bootstrap(best_theta, G_func, G_func_args_tuple, nodes, combos, k, min_energy, dtype)
 
             if energy < min_energy:
                 min_energy = energy
